==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Nástroje bloku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Zobraziť nástroje bloku</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Počiatočné alebo koncové medzery.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Názov bloku je prázdny.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Názov bloku je neplatný.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Blok &apos;%1&apos; už existuje&lt;br&gt;a bude prepísaný.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok už existuje.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Dáta bloku</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Názov bloku:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Nástroje bloku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Zobraziť nástroje bloku</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Blok</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Počiatočné alebo koncové medzery.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Názov bloku je prázdny.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Názov bloku je neplatný.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Blok &apos;%1&apos; už existuje&lt;br&gt;a bude prepísaný.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Blok už existuje.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Dáta bloku</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Názov bloku:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>blok 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="obsolete">Počiatočné alebo koncové medzery.</translation>
    </message>
</context>
</TS>
